Learn R Programming

onetime (version 0.2.0)

set_ok_to_store: Grant or revoke permission to store lockfiles on the user's computer

Description

End users may use this from the command line. Package authors should only call it if they cannot ask for permission interactively using check_ok_to_store(ask = TRUE).

Usage

set_ok_to_store(ok = TRUE)

Value

Invisible NULL.

Arguments

ok

TRUE to grant permission to store lockfiles, FALSE to revoke it and unset options("onetime.dir").

Examples

Run this code
if (FALSE) {
set_ok_to_store()
}

Run the code above in your browser using DataLab